@@ -15,7 +15,7 @@ module.exports = function(weightedProperty, normalised) {
   var extractWeight = function(item, property) {
     if (_.isFunction(property)) { return property(item); }
     if (_.isString(property)) { return item[property]; }
-    throw 'Property must be a function or a property name';
+    throw new Error('Property must be a function or a property name');
   };
 
   var weightCalculatorFn = function() {
