@@ -6,7 +6,7 @@
  */
 
 module.exports = {
-  DeveloperInfo:       require('./developer_info'),
+  DevelopersInfo:      require('./developers_info'),
   Repository:          require('./repository'),
   TimePeriod:          require('./time_interval/time_period'),
   TimeIntervalBuilder: require('./time_interval/builder'),
