@@ -7,7 +7,7 @@
 
 var _         = require('lodash'),
     isStream  = require('is-stream'),
-    Q         = require('q'),
+    Bluebird  = require('bluebird'),
     reporting = require('../../../reporting'),
     logger    = require('../../../log').Logger,
     utils     = require('../../../utils');
@@ -19,7 +19,7 @@ module.exports = function(task, context) {
     if (_.isFunction(task.taskFunction)) {
       try {
         var returnedValue = task.taskFunction.apply(null, [publisher].concat(_.toArray(argsArray)));
-        var promise = isStream(returnedValue) ? utils.stream.streamToPromise(returnedValue) : Q(returnedValue);
+        var promise = isStream(returnedValue) ? utils.stream.streamToPromise(returnedValue) : Bluebird.resolve(returnedValue);
 
         return promise
           .then(publisher.createManifest.bind(publisher))
