@@ -1,4 +1,12 @@
-var PassThrough = require('stream').PassThrough,
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
+var _           = require('lodash'),
+    PassThrough = require('stream').PassThrough,
     logger      = require('../log').Logger,
     utils       = require('../utils');
 
@@ -32,7 +40,7 @@ module.exports = function(jobRunner, streamOptions) {
 
   this.mergeAll = function(streamFnList) {
     counter = new SequenceCounter(streamFnList.length, collectorStream.end.bind(collectorStream));
-    streamFnList.forEach(function(streamFn) {
+    _.each(streamFnList, function(streamFn) {
       jobRunner.addJob(function() {
         return processStream(streamFn());
       });
