@@ -5,6 +5,8 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
+var Bluebird = require('bluebird');
+
 module.exports = function(maxParallelProcs) {
   var maxConcurrentJobs = maxParallelProcs || 1;
   var activeProcs = 0;
@@ -24,7 +26,7 @@ module.exports = function(maxParallelProcs) {
   };
 
   this.addJob = function(jobFn) {
-    jobQueue.push(jobFn);
+    jobQueue.push(Bluebird.method(jobFn));
     executeNext();
   };
 };
