@@ -7,7 +7,7 @@
 
 var _         = require('lodash'),
     filter    = require('through2-filter'),
-    Q         = require('q'),
+    Bluebird  = require('bluebird'),
     pp        = require('../parallel_processing'),
     reporting = require('../reporting'),
     logger    = require('../log').Logger,
@@ -49,16 +49,16 @@ module.exports = function(taskDef, context, helpers) {
           _.wrap(period, tcAnalysis),
           _.wrap(period, ecAnalysis)
         ]).then(function(streamPromises) {
-          if (_.some(streamPromises, { 'state': 'rejected' })) {
-            throw new Error(_.map(_.select(streamPromises, { 'state': 'rejected' }), 'reason'));
+          if (_.some(streamPromises, _.method('isRejected'))) {
+            throw new Error(_.map(_.select(streamPromises, _.method('isRejected')), _.method('reason')));
           }
 
           return new reporting.ReportComposer(helpers.files.sloc())
-            .mergeWith(streamPromises[0].value, {
+            .mergeWith(streamPromises[0].value(), {
               matchStrategy: _.partial(utils.pathMatchers.areCoupledWith, context.parameters.targetFile),
               mergeStrategy: reporting.MergeStrategies.extension(['couplingDegree', 'revisionsAvg'])
             })
-            .mergeWith(streamPromises[1].value, {
+            .mergeWith(streamPromises[1].value(), {
               matchStrategy: utils.pathMatchers.haveSamePath,
               mergeStrategy: reporting.MergeStrategies.extension(['addedLines', 'deletedLines'])
             })
@@ -73,6 +73,6 @@ module.exports = function(taskDef, context, helpers) {
         });
       });
 
-      return Q.all(allReports);
+      return Bluebird.all(allReports);
   });
 };
