@@ -22,7 +22,7 @@ module.exports = function(context) {
     return _.map(data, function(entry) {
       return _.assign(
         _.omit(entry, 'author'),
-        { name: context.developerInfo.find(entry.author)[devInfoProperty] }
+        { name: context.developersInfo.find(entry.author)[devInfoProperty] }
       );
     });
   };
@@ -65,7 +65,7 @@ module.exports = function(context) {
   };
 
   this.aggregateTeamEffortOwnership = function(effortAnalysisData) {
-    if (context.developerInfo.hasTeamInfo) {
+    if (context.developersInfo.hasTeamInfo) {
       return aggregateData(effortAnalysisData, 'team', 'revisions');
     }
   };
@@ -75,7 +75,7 @@ module.exports = function(context) {
   };
 
   this.aggregateTeamCodeOwnership = function(ownershipAnalysisData) {
-    if (context.developerInfo.hasTeamInfo) {
+    if (context.developersInfo.hasTeamInfo) {
       return aggregateData(ownershipAnalysisData, 'team', 'addedLines');
     }
   };
