@@ -5,12 +5,12 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var _      = require('lodash'),
-    map    = require('through2-map'),
-    reduce = require('through2-reduce'),
-    Q      = require('q'),
-    utils  = require('../utils'),
-    pp     = require('../parallel_processing');
+var _        = require('lodash'),
+    map      = require('through2-map'),
+    reduce   = require('through2-reduce'),
+    Bluebird = require('bluebird'),
+    utils    = require('../utils'),
+    pp       = require('../parallel_processing');
 
 module.exports = function(taskDef, context, helpers) {
   taskDef.addAnalysisTask('system-evolution-analysis',
@@ -35,14 +35,14 @@ module.exports = function(taskDef, context, helpers) {
         .pipe(options[streamTransform].call(null, period));
       }));
 
-      return utils.stream.streamToPromise(utils.json.objectArrayToFileStream(reportFile, stream));
+      return utils.stream.streamToPromise(utils.json.objectArrayToFileStream(reportFile, stream)).reflect();
     };
 
     var runAll = function(analyses, streamTransform) {
       var executableAnalyses = _.filter(analyses, function(a) {
         return helpers.codeMaat[a.analysisName].isSupported();
       });
-      return Q.allSettled(_.map(executableAnalyses, _.wrap(streamTransform, runAnalysis)));
+      return Bluebird.all(_.map(executableAnalyses, _.wrap(streamTransform, runAnalysis)));
     };
 
     var systemAnalyses = {
