@@ -14,5 +14,6 @@ module.exports = {
   fileSystem:         require('./file_system'),
   pathMatchers:       require('./path_matchers'),
   platformCheck:      require('./platform_check'),
-  SingletonFactory:   require('./singleton_factory')
+  SingletonFactory:   require('./singleton_factory'),
+  XmlUtils:           require('./xml_utils')
 };
