@@ -5,10 +5,10 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var Q = require('q'),
-    _ = require('lodash');
+var Bluebird = require('bluebird'),
+    _        = require('lodash');
 
-var defaultLayoutAdapter = { toSeries: Q };
+var defaultLayoutAdapter = { toSeries: Bluebird.resolve };
 
 module.exports = function(layoutAdapter, dataTransform) {
   var adapter = layoutAdapter || defaultLayoutAdapter;
