@@ -5,9 +5,9 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var d3 = require('d3'),
-    Q  = require('q'),
-    _  = require('lodash');
+var d3       = require('d3'),
+    Bluebird = require('bluebird'),
+    _        = require('lodash');
 
 var NodeMixin = {
   fullName: function() {
@@ -31,7 +31,7 @@ module.exports = function(options) {
     .padding(2)
     .size([options.diameter, options.diameter]);
 
-  this.toSeries = function(dataTree) {
+  this.toSeries = Bluebird.method(function(dataTree) {
     var rootNode = d3.hierarchy(dataTree);
     rootNode.sum(function(node) {
       return _.ceil(node[options.valueProperty]);
@@ -39,8 +39,8 @@ module.exports = function(options) {
 
     packLayout(rootNode);
 
-    return Q(_.filter(
+    return _.filter(
       _.map(rootNode.descendants(), function(node) { return _.mixin(node, NodeMixin); }),
-      function(node) { return node.hasLayout(); }));
-  };
+      function(node) { return node.hasLayout(); });
+  });
 };
