@@ -9,13 +9,13 @@ var _  = require('lodash');
 
 var mustacheHelper = require('../../helpers/mustache_helper.js');
 
-module.exports = function(config, seriesGroups, diagramScale, colorScale) {
+module.exports = function(configuration, seriesGroups, diagramScale, colorScale) {
   this.dataDefinitions = _.map(seriesGroups, function(namedSeries) {
     return {
       name: 'dots-' + namedSeries.name,
       componentType: 'data',
       properties: {
-        offset: { x: config.style.margin.left,  y: config.style.margin.top },
+        offset: { x: configuration.style.margin.left,  y: configuration.style.margin.top },
         attributes: { class: 'dots' }
       },
       series: namedSeries.allValues(),
@@ -25,9 +25,9 @@ module.exports = function(config, seriesGroups, diagramScale, colorScale) {
           properties: {
             attributes: {
               r: 3,
-              cx: function(d) { return diagramScale.x(d[config.plotLine.scatterPoints.valueProperty.x]); },
-              cy: function(d) { return diagramScale.y(d[config.plotLine.scatterPoints.valueProperty.y]); },
-              'clip-path': 'url(#clip)'
+              cx: function(d) { return diagramScale.x(d[configuration.plotLine.scatterPoints.valueProperty.x]); },
+              cy: function(d) { return diagramScale.y(d[configuration.plotLine.scatterPoints.valueProperty.y]); },
+              'clip-path': 'url(#clip-' + configuration.plotName + ')'
             },
             style: { fill: colorScale(namedSeries.name) }
           },
@@ -37,10 +37,10 @@ module.exports = function(config, seriesGroups, diagramScale, colorScale) {
               style: { color: colorScale(namedSeries.name) },
               html: function(d) {
                 return mustacheHelper.renderTemplate.apply(null, [
-                  config.tooltipInfo.templateId,
+                  configuration.tooltipInfo.templateId,
                   {
                     title: namedSeries.name,
-                    data: _.map(config.tooltipInfo.templateProperties, function(prop) {
+                    data: _.map(configuration.tooltipInfo.templateProperties, function(prop) {
                       return {
                         label: prop.label,
                         value: (prop.transform || _.identity)(d[prop.valueProperty])
@@ -68,9 +68,9 @@ module.exports = function(config, seriesGroups, diagramScale, colorScale) {
           elementSelection: 'circle',
           properties: {
             attributes: {
-              cx: function(d) { return diagramScale.x(d[config.plotLine.scatterPoints.valueProperty.x]); },
-              cy: function(d) { return diagramScale.y(d[config.plotLine.scatterPoints.valueProperty.y]); },
-              'clip-path': 'url(#clip)'
+              cx: function(d) { return diagramScale.x(d[configuration.plotLine.scatterPoints.valueProperty.x]); },
+              cy: function(d) { return diagramScale.y(d[configuration.plotLine.scatterPoints.valueProperty.y]); },
+              'clip-path': 'url(#clip-' + configuration.plotName + ')'
             }
           }
         }
