@@ -6,7 +6,7 @@
  */
 
 var mustache = require('mustache'),
-    Q        = require('q');
+    Bluebird = require('bluebird');
 
 var asyncLoader = require('../utils/async_loader.js');
 
@@ -25,7 +25,7 @@ module.exports = {
     return mustache.render(parsedTemplates[id], data);
   },
   loadTemplate: function(tmpl) {
-    if (parsedTemplates[tmpl.id]) { return Q(); }
+    if (parsedTemplates[tmpl.id]) { return Bluebird.resolve(); }
 
     return asyncLoader.loadTemplate(tmpl.file).then(function(content) {
       if (parsedTemplates[tmpl.id]) { return; }
