@@ -5,9 +5,9 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var _  = require('lodash'),
-    Q  = require('q'),
-    ko = require('knockout');
+var _        = require('lodash'),
+    Bluebird = require('bluebird'),
+    ko       = require('knockout');
 
 var asyncLoader       = require('../utils/async_loader.js'),
     mustacheHelper    = require('../helpers/mustache_helper.js'),
@@ -58,7 +58,7 @@ var GraphModel = function(graphModelConfig) {
   this.diagram = new Diagram(graphModelConfig.id, graphModelConfig.diagram);
 
   this.initialize = function() {
-    return Q.all(
+    return Bluebird.all(
       controlTemplatePromises()
         .concat(viewTemplatePromises())
         .concat(
