@@ -32,14 +32,12 @@ module.exports = function(manifest) {
           viewTemplates: ['elementInfo3TooltipTemplate'],
           diagram: {
             Model: Model,
-            layoutAdapter: new LayoutAdapter({ diameter: 950, valueProperty: 'totalLines' }),
-            graphHandlers: [new ZoomHandler({ diameter: 950 })],
+            layoutAdapter: new LayoutAdapter({ diameter: 1000, valueProperty: 'totalLines' }),
+            graphHandlers: [new ZoomHandler({ diameter: 1000 })],
             configuration: {
               style: {
                 cssClass: 'circle-packing-diagram temporal-coupling',
-                width: 960,
-                height: 960,
-                diameter: 950,
+                diameter: 1000,
                 nodeDepthColorRange: ['hsl(185,60%,99%)', 'hsl(187,40%,70%)'],
                 weightedNodeColor: '#990012',
                 nodeHighlight: { name: modulePath, color: '#1269FC' }
