@@ -5,7 +5,7 @@
  * see http://www.gnu.org/licenses/gpl.html
  */
 
-var Q = require('q');
+var Bluebird = require('bluebird');
 
 var templateExists = function(id) {
   return window.document.getElementById(id) !== null;
@@ -17,7 +17,7 @@ module.exports = {
     .then(function(response) { return response.text(); });
   },
   loadTemplateIntoDocument: function(id, file) {
-    if (templateExists(id)) { return Q(); }
+    if (templateExists(id)) { return Bluebird.resolve(); }
 
     return this.loadTemplate(file).then(function(content) {
       if (!templateExists(id)) {
